@@ -6,9 +6,12 @@ from pytorch_pfn_extras import config  # NOQA
 from pytorch_pfn_extras import cuda  # NOQA
 from pytorch_pfn_extras import dataset  # NOQA
 from pytorch_pfn_extras import dataloaders  # NOQA
+from pytorch_pfn_extras import engine  # NOQA
+from pytorch_pfn_extras import handler  # NOQA
 from pytorch_pfn_extras import nn  # NOQA
 from pytorch_pfn_extras import profiler  # NOQA
 from pytorch_pfn_extras import reporting  # NOQA
+from pytorch_pfn_extras import runtime  # NOQA
 from pytorch_pfn_extras import training  # NOQA
 from pytorch_pfn_extras import utils  # NOQA
 from pytorch_pfn_extras import writing  # NOQA
@@ -18,5 +21,6 @@ from pytorch_pfn_extras._tensor import as_ndarray  # NOQA
 from pytorch_pfn_extras._tensor import get_xp  # NOQA
 from pytorch_pfn_extras._tensor import as_numpy_dtype  # NOQA
 from pytorch_pfn_extras._tensor import from_numpy_dtype  # NOQA
+from pytorch_pfn_extras.runtime._to import to  # NOQA
 
 from pytorch_pfn_extras._version import __version__  # NOQA
