@@ -1,8 +1,6 @@
-# mypy: ignore-errors
-
 import queue
 import time
-from typing import Optional
+from typing import Any, Iterable, List, Optional, Tuple, Union, TYPE_CHECKING
 
 import torch
 
@@ -10,14 +8,29 @@ import pytorch_pfn_extras.engine
 import pytorch_pfn_extras.training
 from pytorch_pfn_extras.training import extension as extension
 from pytorch_pfn_extras.training import trigger as trigger_module
+from pytorch_pfn_extras.training import manager as manager_module
 import pytorch_pfn_extras.reporting as reporting
 from pytorch_pfn_extras.profiler import record
 
+from pytorch_pfn_extras.training.trigger import Trigger, TriggerLike
+
+if TYPE_CHECKING:
+    import pytorch_pfn_extras.handler as handler_module
+    from pytorch_pfn_extras.training._evaluator import _Evaluator
+    from pytorch_pfn_extras.profiler._time_summary import _ReportNotification
+
 
 class _Trainer(pytorch_pfn_extras.engine._Engine):
-    def __init__(self, handler, *, evaluator, **kwargs):
+    def __init__(
+            self,
+            handler: 'handler_module.BaseHandler',
+            *,
+            evaluator: Optional[Union['_Evaluator', Tuple['_Evaluator', TriggerLike]]],
+            **kwargs: Any,
+    ):
         super().__init__(handler, **kwargs)
-        if type(evaluator) is tuple:
+        if isinstance(evaluator, tuple):
+            self.evaluator: Optional['_Evaluator'] = None
             self.evaluator, trigger = evaluator
             self.evaluator_trigger = trigger_module.get_trigger(trigger)
         else:
@@ -26,39 +39,45 @@ class _Trainer(pytorch_pfn_extras.engine._Engine):
         self.val_loader = None
 
     @property
-    def epoch(self):
+    def epoch(self) -> int:
         return self.manager.epoch
 
     @property
-    def epoch_detail(self):
+    def epoch_detail(self) -> float:
         return self.manager.epoch_detail
 
     @property
-    def iteration(self):
+    def iteration(self) -> int:
         return self.manager.iteration
 
     @property
-    def is_before_training(self):
+    def is_before_training(self) -> bool:
         return self.manager.iteration == 0
 
     @property
-    def stop_trigger(self):
+    def stop_trigger(self) -> Trigger:
         return self._stop_trigger
 
     @stop_trigger.setter
-    def stop_trigger(self, trigger):
+    def stop_trigger(self, trigger: Trigger) -> None:
         self._stop_trigger = trigger
 
-    def get_optimizer(self, name):
+    def get_optimizer(self, name: str) -> torch.optim.Optimizer:
         return self.manager.optimizers[name]
 
-    def set_optimizer(self, name, optimizer):
-        self.manager.optimizers[name] = optimizer
+    def set_optimizer(self, name: str, optimizer: torch.optim.Optimizer) -> None:
+        self.manager.optimizers[name] = optimizer  # type: ignore[index]
 
-    def is_epoch_last_iter(self, idx):
+    def is_epoch_last_iter(self, idx: int) -> bool:
         return (idx + 1) == (self.manager._iters_per_epoch)
 
-    def _complete_step(self, idx, outs, *, is_deferred=False):
+    def _complete_step(
+            self,
+            idx: int,
+            outs: Any,
+            *,
+            is_deferred: bool = False,
+    ) -> None:
         self._deferred = False  # notify that the function was called
         c_idx = self._idxs.get()
         # Asure that iterations complete in order
@@ -97,17 +116,20 @@ class _Trainer(pytorch_pfn_extras.engine._Engine):
             record_run_iteration.complete()
             record_iteration.complete()
 
-    def _run_evaluator(self):
+    def _run_evaluator(self) -> None:
+        assert self.evaluator is not None
+        if self._val_loader is None:
+            raise ValueError('"val_loader" is not given.')
         self.evaluator.handler.train_validation_begin(self, self.evaluator)
         self.evaluator.run(self._val_loader, eval_len=self._eval_len)
         self.evaluator.handler.train_validation_end(self, self.evaluator)
 
-    def run(self,
-            train_loader: torch.utils.data.DataLoader,
-            val_loader: Optional[torch.utils.data.DataLoader] = None,
+    def run(self,  # type: ignore[override]
+            train_loader: Iterable[Any],
+            val_loader: Optional[Iterable[Any]] = None,
             *,
             train_len: Optional[int] = None,
-            eval_len: Optional[int] = None):
+            eval_len: Optional[int] = None) -> None:
         """Executes the training loop.
 
         Args:
@@ -126,23 +148,24 @@ class _Trainer(pytorch_pfn_extras.engine._Engine):
             - :meth:`pytorch_pfn_extras.training._evaluator._Evaluator`
         """
         if train_len is None:
-            train_len = len(train_loader)
+            train_len = len(train_loader)  # type: ignore[arg-type]
 
         self._val_loader = val_loader
         self._eval_len = eval_len
 
         class _EvaluatorExt:
-            def __init__(self, trainer):
+            def __init__(self, trainer: '_Trainer') -> None:
                 self.name = 'Evaluator'
                 self.needs_model_state = True
                 self._trainer = trainer
 
-            def __call__(self, manager):
+            def __call__(self, manager: manager_module._BaseExtensionsManager) -> None:
                 self._trainer._run_evaluator()
 
         if self._manager is None:
             self._setup_manager(train_len)
-            if self.evaluator is not None:
+            assert isinstance(self._manager, manager_module._BaseExtensionsManager)
+            if self.evaluator is not None:  # type: ignore[unreachable]
                 # Register the evaluator as an extension to the manager
                 # To be triggered with the correct timing
                 self._manager.extend(
@@ -159,14 +182,15 @@ class _Trainer(pytorch_pfn_extras.engine._Engine):
 
             # When iterations are completed in the callback
             # This is needed to avoid being constantly passing parameters
-            self._idxs = queue.Queue()
-            self._inputs = queue.Queue()
-            self._times = queue.Queue()
-            self._observed = queue.Queue()
+            self._idxs: 'queue.Queue[int]' = queue.Queue()
+            self._inputs: 'queue.Queue[Any]' = queue.Queue()
+            self._times: 'queue.Queue[float]' = queue.Queue()
+            self._observed: 'queue.Queue[reporting.Observation]' = queue.Queue()
             # Iterator must be created after `train_epoch_begin` as it may be
             #  using a DistributedSampler.
             loader_iter = iter(train_loader)
-            self._profile_records = queue.Queue()
+            self._profile_records: 'queue.Queue[List[_ReportNotification]]' \
+                = queue.Queue()
             for idx in range(train_len):
                 with record(
                     "pytorch_pfn_extras.training.Trainer:iteration",
