@@ -1,12 +1,11 @@
-# mypy: ignore-errors
-
 import collections
 import contextlib
 import copy
 from pytorch_pfn_extras.profiler import record
 import time
-from typing import Any, Dict, Generator, List, Optional, Union
-from typing import TYPE_CHECKING
+from typing import (
+    Any, Dict, Iterable, Generator, List, Mapping, Optional, Union, TYPE_CHECKING
+)
 import warnings
 
 import torch
@@ -16,16 +15,18 @@ from pytorch_pfn_extras import reporting
 from pytorch_pfn_extras.training import extension as extension_module
 from pytorch_pfn_extras.training import trigger as trigger_module
 from pytorch_pfn_extras.training import _util as util_module
-from pytorch_pfn_extras.training._transform_model import default_transform_model
+from pytorch_pfn_extras.training._transform_model import (
+    default_transform_model, _TransformModel,
+)
 
 _get_time = time.perf_counter
 
 
 class IterationNotification:
-    def __init__(self):
+    def __init__(self) -> None:
         self._is_completed = True
 
-    def defer(self):
+    def defer(self) -> None:
         self._is_completed = False
 
 
@@ -35,25 +36,25 @@ class _ManagerExecutionProxy:
     require to measure executions when using async mode
     Note that in sync mode execution == iteration
     """
-    def __init__(self, manager):
+    def __init__(self, manager: '_BaseExtensionsManager') -> None:
         self._manager = manager
 
     @property
-    def iteration(self):
+    def iteration(self) -> int:
         return self._manager.execution
 
     @property
-    def epoch(self):
+    def epoch(self) -> int:
         # Extensions will start via self.iteration
         return self.iteration // self._iters_per_epoch
 
     @property
-    def epoch_detail(self):
+    def epoch_detail(self) -> float:
         # Extensions will start via self.iteration
         return self.iteration / self._iters_per_epoch
 
     @property
-    def _iters_per_epoch(self):
+    def _iters_per_epoch(self) -> int:
         return self._manager._iters_per_epoch
 
 
@@ -64,14 +65,15 @@ class _BaseExtensionsManager:
 
     def __init__(
             self,
-            models: Union[torch.nn.Module, Dict[str, torch.nn.Module]],
-            optimizers: Union[torch.optim.Optimizer, Dict[str, torch.optim.Optimizer]],
+            models: Union[torch.nn.Module, Mapping[str, torch.nn.Module]],
+            optimizers: Union[torch.optim.Optimizer,
+                              Mapping[str, torch.optim.Optimizer]],
             max_epochs: int,
             extensions: Optional[List['extension_module.ExtensionLike']],
             out_dir: str,
             writer: Optional[writing.Writer],
             stop_trigger: 'trigger_module.TriggerLike' = None,
-            transform_model=default_transform_model,
+            transform_model: _TransformModel = default_transform_model,
     ) -> None:
         if extensions is None:
             extensions = []
@@ -98,19 +100,19 @@ class _BaseExtensionsManager:
         # models before starting a training loop.
         self._model_available = True
 
-        if not isinstance(models, dict):
+        if isinstance(models, collections.abc.Mapping):
+            self._models = models
+        else:
             if not isinstance(models, torch.nn.Module):
                 raise ValueError(
                     'model must be an instance of dict or toch.nn.Module')
             self._models = {'main': models}
+        if isinstance(optimizers, collections.abc.Mapping):
+            self._optimizers = optimizers
         else:
-            self._models = models
-        if not isinstance(optimizers, dict):
             # TODO(ecastill) Optimizer type is not checked because of tests
             # using mocks and other classes
             self._optimizers = {'main': optimizers}
-        else:
-            self._optimizers = optimizers
 
         for name, model in self._models.items():
             # TODO we should not initialize extensions at this point
@@ -123,7 +125,7 @@ class _BaseExtensionsManager:
         self._start_iteration = 0
         # Defer!
         self._start_time: Optional[float] = None
-        self._iters_per_epoch: Optional[int] = None
+        self.__iters_per_epoch: Optional[int] = None
         self._extensions: Dict[
             str, extension_module.ExtensionEntry] = collections.OrderedDict()
         for ext in extensions:
@@ -144,7 +146,7 @@ class _BaseExtensionsManager:
     def iteration(self, value: int) -> None:
         self._iteration = value
 
-    def _check_model_available(self):
+    def _check_model_available(self) -> None:
         if self._model_available:
             return
         raise RuntimeError(
@@ -161,13 +163,13 @@ class _BaseExtensionsManager:
         return models
 
     @property
-    def raw_models(self):
+    def raw_models(self) -> Mapping[str, torch.nn.Module]:
         self.start_extensions()
         self._check_model_available()
         return self._models
 
     @property
-    def optimizers(self) -> Dict[str, torch.optim.Optimizer]:
+    def optimizers(self) -> Mapping[str, torch.optim.Optimizer]:
         self.start_extensions()
         return self._optimizers
 
@@ -186,15 +188,18 @@ class _BaseExtensionsManager:
     @property
     def epoch(self) -> int:
         # Extensions will start via self.iteration
-        assert self._iters_per_epoch is not None
         return self.iteration // self._iters_per_epoch
 
     @property
     def epoch_detail(self) -> float:
         # Extensions will start via self.iteration
-        assert self._iters_per_epoch is not None
         return self.iteration / self._iters_per_epoch
 
+    @property
+    def _iters_per_epoch(self) -> int:
+        assert self.__iters_per_epoch is not None
+        return self.__iters_per_epoch
+
     @property
     def stop_trigger(self) -> bool:
         self.start_extensions()
@@ -222,7 +227,11 @@ class _BaseExtensionsManager:
             ' `snapshot_iter_{.iteration}`).', DeprecationWarning)
         return self
 
-    def _get_proxy_for_trigger(self, trigger):
+    # TODO(asi1024): Add type annotation of return value.
+    def _get_proxy_for_trigger(
+            self,
+            trigger: 'trigger_module.Trigger',
+    ) -> Any:
         if isinstance(trigger, trigger_module.IntervalTrigger):
             return _ManagerExecutionProxy(self)
         return self
@@ -235,7 +244,7 @@ class _BaseExtensionsManager:
     ) -> None:
         self.iteration = start_iteration
         self.execution = start_execution
-        self._iters_per_epoch = iters_per_epoch
+        self.__iters_per_epoch = iters_per_epoch
 
     def start_extensions(self) -> None:
         if self._start_extensions_called:
@@ -359,7 +368,8 @@ class _BaseExtensionsManager:
         else:
             raise ValueError('extension %s not found' % name)
 
-    def run_extensions(self, *, completed=True, only_iterations=True) -> None:
+    def run_extensions(
+            self, *, completed: bool = True, only_iterations: bool = True) -> None:
         if completed:
             # Check if the model is available for the iteration just
             # completed, i.e., the iteration number is already incremented.
@@ -411,11 +421,11 @@ class _BaseExtensionsManager:
                 extension(self)
         self._model_available = True
 
-    def needs_state_this_iteration(self):
+    def needs_state_this_iteration(self) -> bool:
         # TODO(kmaehashi) remove this interface after migration complete.
         return self.needs_model_state(self.execution + 1)
 
-    def needs_model_state(self, iteration=None):
+    def needs_model_state(self, iteration: Optional[int] = None) -> bool:
         if iteration is None:
             # Iteration is added one, because iteration count
             # is increased just right before calling extensions
@@ -499,24 +509,29 @@ class ExtensionsManager(_BaseExtensionsManager):
             optimizers: Union[torch.optim.Optimizer, Dict[str, torch.optim.Optimizer]],
             max_epochs: int,
             *,
-            iters_per_epoch: Optional[int],
+            iters_per_epoch: int,
             extensions: Optional[List['extension_module.ExtensionLike']] = None,
             out_dir: str = 'result',
             stop_trigger: 'trigger_module.TriggerLike' = None,
             writer: Optional[writing.Writer] = None,
-            transform_model=lambda n, x: x,
+            transform_model: _TransformModel = lambda n, x: x,
     ) -> None:
         super().__init__(
             models, optimizers, max_epochs, extensions,
             out_dir, writer, stop_trigger, transform_model)
-        if not (isinstance(iters_per_epoch, int) and iters_per_epoch >= 1):
+        if iters_per_epoch < 1:
             raise ValueError(
                 'iters_per_epoch must be an integer >= 1 ({} given)'.format(
                     iters_per_epoch))
         self._prepare_for_training(0, 0, iters_per_epoch)
 
     @contextlib.contextmanager
-    def complete_iteration(self, *, observation=None, step_optimizers=None):
+    def complete_iteration(
+            self,
+            *,
+            observation: Optional[reporting.Observation] = None,
+            step_optimizers: Optional[Iterable[str]] = None,
+    ) -> Generator[None, None, None]:
         """ Context manager to complete deferred iterations.
 
         Args:
@@ -529,7 +544,7 @@ class ExtensionsManager(_BaseExtensionsManager):
 
         if observation is None:
             observation = {}
-        step_optimizers_names = []
+        step_optimizers_names: Iterable[str] = []
         if step_optimizers is not None:
             step_optimizers_names = step_optimizers
         self.observation = observation
@@ -549,7 +564,7 @@ class ExtensionsManager(_BaseExtensionsManager):
             self,
             *,
             step_optimizers: Optional[List[str]] = None
-    ) -> Generator[None, None, None]:
+    ) -> Generator[IterationNotification, None, None]:
         """Context manager to run an iteration.
 
         This manager can additionally run a step in the
@@ -618,8 +633,9 @@ class IgniteExtensionsManager(_BaseExtensionsManager):
     def __init__(
             self,
             engine: 'ignite.engine.Engine',
-            models: Union[torch.nn.Module, Dict[str, torch.nn.Module]],
-            optimizers: Union[torch.optim.Optimizer, Dict[str, torch.optim.Optimizer]],
+            models: Union[torch.nn.Module, Mapping[str, torch.nn.Module]],
+            optimizers: Union[torch.optim.Optimizer,
+                              Mapping[str, torch.optim.Optimizer]],
             max_epochs: int,
             *,
             extensions: Optional[List['extension_module.ExtensionLike']] = None,
@@ -652,7 +668,7 @@ class IgniteExtensionsManager(_BaseExtensionsManager):
 
         @self.engine.on(Events.STARTED)
         def set_training_started(engine: Engine) -> None:
-            iters_per_epoch = len(engine.state.dataloader)
+            iters_per_epoch = len(engine.state.dataloader)  # type: ignore[arg-type]
             # Initialize manager once before extensions' `initialize` call
             self._prepare_for_training(0, 0, iters_per_epoch)
             self.start_extensions()
