@@ -1,6 +1,14 @@
+# mypy: ignore-errors
+
+from typing import Any, Dict, TYPE_CHECKING
+
 from pytorch_pfn_extras.training import trigger
 
 
+if TYPE_CHECKING:
+    from pytorch_pfn_extras.training.manager import _BaseExtensionsManager
+
+
 class OnceTrigger(trigger.Trigger):
 
     """Trigger based on the starting point of the iteration.
@@ -20,23 +28,26 @@ class OnceTrigger(trigger.Trigger):
 
     """
 
-    def __init__(self, call_on_resume=False):
+    def __init__(self, call_on_resume: bool = False) -> None:
         self._flag_first = True
         self._flag_resumed = call_on_resume
 
     @property
-    def finished(self):
+    def finished(self) -> bool:
         return not (self._flag_first or self._flag_resumed)
 
-    def __call__(self, manager):
+    def __call__(self, manager: '_BaseExtensionsManager') -> bool:
         fire = not self.finished
         self._flag_resumed = False
         self._flag_first = False
         return fire
 
-    def state_dict(self):
+    def state_dict(self) -> Dict[str, Any]:
         state = {'_flag_first': self._flag_first}
         return state
 
-    def load_state_dict(self, to_load):
+    def load_state_dict(self, to_load: Dict[str, Any]) -> None:
         self._flag_first = to_load['_flag_first']
+
+    def may_fire(self, iteration, epoch_length):
+        return not (self._flag_first or self._flag_resumed)
